@@ -1,8 +1,8 @@
 """
-Module: 'math' on micropython-v1.18-pyboard
+Module: 'math' on micropython-v1.19.1-stm32
 """
-# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
-# Stubber: 1.5.4
+# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
+# Stubber: 1.5.6
 from typing import Any
 
 
@@ -101,6 +101,9 @@ def gamma(*args, **kwargs) -> Any:
     ...
 
 
+inf = inf  # type: float
+
+
 def isclose(*args, **kwargs) -> Any:
     ...
 
@@ -141,6 +144,7 @@ def modf(*args, **kwargs) -> Any:
     ...
 
 
+nan = nan  # type: float
 pi = 3.141593  # type: float
 
 
@@ -168,5 +172,8 @@ def tanh(*args, **kwargs) -> Any:
     ...
 
 
+tau = 6.283185  # type: float
+
+
 def trunc(*args, **kwargs) -> Any:
     ...
