@@ -1,8 +1,8 @@
 """
-Module: 'stm' on micropython-v1.18-pyboard
+Module: 'stm' on micropython-v1.19.1-stm32
 """
-# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
-# Stubber: 1.5.4
+# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
+# Stubber: 1.5.6
 from typing import Any
 
 ADC1 = 1073815552  # type: int
@@ -257,6 +257,8 @@ USART_CR3 = 20  # type: int
 USART_DR = 4  # type: int
 USART_GTPR = 24  # type: int
 USART_SR = 0  # type: int
+USB_OTG_FS = 1342177280  # type: int
+USB_OTG_HS = 1074003968  # type: int
 WWDG = 1073753088  # type: int
 WWDG_CFR = 4  # type: int
 WWDG_CR = 0  # type: int
