@@ -1,8 +1,8 @@
 """
-Module: 'sys' on micropython-v1.18-pyboard
+Module: 'sys' on micropython-v1.19.1-stm32
 """
-# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
-# Stubber: 1.5.4
+# MCU: {'ver': 'v1.19.1', 'build': '', 'platform': 'stm32', 'port': 'stm32', 'machine': 'PYBv1.1 with STM32F405RG', 'release': '1.19.1', 'nodename': 'pyboard', 'name': 'micropython', 'family': 'micropython', 'sysname': 'pyboard', 'version': '1.19.1'}
+# Stubber: 1.5.6
 from typing import Any
 
 argv = []  # type: list
@@ -24,8 +24,10 @@ def print_exception(*args, **kwargs) -> Any:
     ...
 
 
+ps1 = ">>> "  # type: str
+ps2 = "... "  # type: str
 stderr: Any  ## <class 'FileIO'> = <io.FileIO 2>
 stdin: Any  ## <class 'FileIO'> = <io.FileIO 0>
 stdout: Any  ## <class 'FileIO'> = <io.FileIO 1>
-version = "3.4.0"  # type: str
+version = "3.4.0; MicroPython v1.19.1 on 2022-06-18"  # type: str
 version_info = ()  # type: tuple
